/*
 * Knight Rider light show
 *
 */

#include "DSP28x_Project.h"     // Device Headerfile and Examples Include File

#include "f2802x_common/include/flash.h"
#include "f2802x_common/include/gpio.h"
#include "f2802x_common/include/F2802x_Examples.h"
#include "f2802x_common/include/pll.h"

#define LIGHTSHOW_CNT 6

FLASH_Handle myFlash;

void knight_rider(void) {
	static int cnt=0;
    const int lightshow[LIGHTSHOW_CNT] = {0x1, 0x2, 0x4, 0x8, 0x4, 0x2};

    // LEDs are low active on C2000 launch pad
    GpioDataRegs.GPADAT.all =  (GpioDataRegs.GPADAT.all & ~0xF) | ~lightshow[cnt] & 0xF;
    if (++cnt >= LIGHTSHOW_CNT) cnt=0;
}

int main(void) {

	PLL_Handle myPll;

    myFlash = FLASH_init((void *)FLASH_BASE_ADDR, sizeof(FLASH_Obj));

    // If running from flash copy RAM only functions to RAM
#ifdef _FLASH
    memcpy(&RamfuncsRunStart, &RamfuncsLoadStart, (size_t)&RamfuncsLoadSize);
    FLASH_setup(myFlash);
#endif

// Initialisierung

    // Setup the PLL for x12 /2 which will yield 60Mhz = 10Mhz * 12 / 2
    myPll = PLL_init((void *)PLL_BASE_ADDR, sizeof(PLL_Obj));
    PLL_setup(myPll, PLL_Multiplier_12, PLL_DivideSelect_ClkIn_by_2);

    // IOs
    EALLOW;
    GpioCtrlRegs.GPADIR.all=0xF;		// GPIO0-3 outputs
    GpioCtrlRegs.GPAPUD.bit.GPIO12=1;	// external pull down on GPIO12 in C2000 launch pad
    EDIS;

    while (1) {
    	if (!GpioDataRegs.GPADAT.bit.GPIO12) {
    		knight_rider();
    	} else {
    		// pause light show, do nothing
    	}
    	DELAY_US(100000);
    }
}
